/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM calIRecurrenceInfo.idl
 */

#ifndef __gen_calIRecurrenceInfo_h__
#define __gen_calIRecurrenceInfo_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class calIItemBase; /* forward declaration */

class calIDateTime; /* forward declaration */

class calIRecurrenceItem; /* forward declaration */

class calIIcalProperty; /* forward declaration */


/* starting interface:    calIRecurrenceInfo */
#define CALIRECURRENCEINFO_IID_STR "8ca5db89-2583-4f0c-b845-4a6d2f229efd"

#define CALIRECURRENCEINFO_IID \
  {0x8ca5db89, 0x2583, 0x4f0c, \
    { 0xb8, 0x45, 0x4a, 0x6d, 0x2f, 0x22, 0x9e, 0xfd }}

class NS_NO_VTABLE calIRecurrenceInfo : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(CALIRECURRENCEINFO_IID)

  /* readonly attribute boolean isMutable; */
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable) = 0;

  /* void makeImmutable (); */
  NS_IMETHOD MakeImmutable(void) = 0;

  /* calIRecurrenceInfo clone (); */
  NS_IMETHOD Clone(calIRecurrenceInfo **_retval) = 0;

  /* attribute calIItemBase item; */
  NS_IMETHOD GetItem(calIItemBase * *aItem) = 0;
  NS_IMETHOD SetItem(calIItemBase * aItem) = 0;

  /**
   * The start date of an item is directly referenced by parts of calIRecurrenceInfo,
   * thus changing the former without adjusting the latter would break the internal structure.
   * This method provides the necessary functionality. There's no need to call it manually
   * after writing to the start date of an item, since it's called automatically in the
   * appropriate setter of an item.
   */
  /* void onStartDateChange (in calIDateTime aNewStartTime, in calIDateTime aOldStartTime); */
  NS_IMETHOD OnStartDateChange(calIDateTime *aNewStartTime, calIDateTime *aOldStartTime) = 0;

  /* void getRecurrenceItems (out unsigned long aCount, [array, size_is (aCount), retval] out calIRecurrenceItem aItems); */
  NS_IMETHOD GetRecurrenceItems(PRUint32 *aCount, calIRecurrenceItem ***aItems) = 0;

  /* void setRecurrenceItems (in unsigned long aCount, [array, size_is (aCount)] in calIRecurrenceItem aItems); */
  NS_IMETHOD SetRecurrenceItems(PRUint32 aCount, calIRecurrenceItem **aItems) = 0;

  /* unsigned long countRecurrenceItems (); */
  NS_IMETHOD CountRecurrenceItems(PRUint32 *_retval) = 0;

  /* void clearRecurrenceItems (); */
  NS_IMETHOD ClearRecurrenceItems(void) = 0;

  /* void appendRecurrenceItem (in calIRecurrenceItem aItem); */
  NS_IMETHOD AppendRecurrenceItem(calIRecurrenceItem *aItem) = 0;

  /* calIRecurrenceItem getRecurrenceItemAt (in unsigned long aIndex); */
  NS_IMETHOD GetRecurrenceItemAt(PRUint32 aIndex, calIRecurrenceItem **_retval) = 0;

  /* void deleteRecurrenceItemAt (in unsigned long aIndex); */
  NS_IMETHOD DeleteRecurrenceItemAt(PRUint32 aIndex) = 0;

  /* void deleteRecurrenceItem (in calIRecurrenceItem aItem); */
  NS_IMETHOD DeleteRecurrenceItem(calIRecurrenceItem *aItem) = 0;

  /* void insertRecurrenceItemAt (in calIRecurrenceItem aItem, in unsigned long aIndex); */
  NS_IMETHOD InsertRecurrenceItemAt(calIRecurrenceItem *aItem, PRUint32 aIndex) = 0;

  /**
   * isFinite is true if the recurrence items specify a finite number
   * of occurrences.  This is useful for UI and for possibly other users.
   */
  /* readonly attribute boolean isFinite; */
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite) = 0;

  /**
   * This is a shortcut to appending or removing a single negative date
   * assertion. aRecurrenceId needs to be a normal recurrence id, it may not be
   * RDATE.
   */
  /* void removeOccurrenceAt (in calIDateTime aRecurrenceId); */
  NS_IMETHOD RemoveOccurrenceAt(calIDateTime *aRecurrenceId) = 0;

  /* void restoreOccurrenceAt (in calIDateTime aRecurrenceId); */
  NS_IMETHOD RestoreOccurrenceAt(calIDateTime *aRecurrenceId) = 0;

  /**
   * Modify an a particular occurrence with the given exception proxy
   * item.  If the recurrenceId isn't an already existing exception item,
   * a new exception is added.  Otherwise, the existing exception
   * is modified.
   *
   * The item's parentItem must be equal to this RecurrenceInfo's
   * item. <-- XXX check this, compare by calendar/id only
   *
   * @param anItem exceptional/overridden item
   * @param aTakeOverOwnership whether the recurrence info object can take over
   *        the item or needs to clone it
   */
  /* void modifyException (in calIItemBase anItem, in boolean aTakeOverOwnership); */
  NS_IMETHOD ModifyException(calIItemBase *anItem, PRBool aTakeOverOwnership) = 0;

  /**
   * Return an existing exception item for the given recurrence ID.
   * If an exception does not exist, and aCreate is set, a new one
   * is created and returned.  Otherwise, null is returned.
   */
  /* calIItemBase getExceptionFor (in calIDateTime aRecurrenceId, in boolean aCreate); */
  NS_IMETHOD GetExceptionFor(calIDateTime *aRecurrenceId, PRBool aCreate, calIItemBase **_retval) = 0;

  /**
   * Removes an exception item for the given recurrence ID, if
   * any exist.
   */
  /* void removeExceptionFor (in calIDateTime aRecurrenceId); */
  NS_IMETHOD RemoveExceptionFor(calIDateTime *aRecurrenceId) = 0;

  /**
   * Returns a list of all recurrence ids that have exceptions.
   */
  /* void getExceptionIds (out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aIds); */
  NS_IMETHOD GetExceptionIds(PRUint32 *aCount, calIDateTime ***aIds) = 0;

  /* calIItemBase getOccurrenceFor (in calIDateTime aRecurrenceId); */
  NS_IMETHOD GetOccurrenceFor(calIDateTime *aRecurrenceId, calIItemBase **_retval) = 0;

  /**
   * Return the chronologically next occurrence after aTime. This takes
   * exceptions and EXDATE/RDATEs into account.
   *
   * @param aTime           The (exclusive) date to start searching.
   * @return                The next occurrence, or null if there is none.
   */
  /* calIItemBase getNextOccurrence (in calIDateTime aTime); */
  NS_IMETHOD GetNextOccurrence(calIDateTime *aTime, calIItemBase **_retval) = 0;

  /**
   * Return the chronologically previous occurrence after aTime. This takes
   * exceptions and EXDATE/RDATEs into account.
   *
   * @param aTime           The (exclusive) date to start searching.
   * @return                The previous occurrence, or null if there is none.
   */
  /* calIItemBase getPreviousOccurrence (in calIDateTime aTime); */
  NS_IMETHOD GetPreviousOccurrence(calIDateTime *aTime, calIItemBase **_retval) = 0;

  /**
   * Return an array of calIDateTime representing all start times of this event
   * between start (inclusive) and end (non-inclusive). Exceptions are taken
   * into account.
   *
   * @param aRangeStart     The (inclusive) date to start searching.
   * @param aRangeEnd       The (exclusive) date to end searching.
   * @param aMaxCount       The maximum number of dates to return
   *
   * @param aCount          The number of dates returned.
   * @return                The array of dates.
   */
  /* void getOccurrenceDates (in calIDateTime aRangeStart, in calIDateTime aRangeEnd, in unsigned long aMaxCount, out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aDates); */
  NS_IMETHOD GetOccurrenceDates(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates) = 0;

  /**
   * Return an array of calIItemBase representing all occurrences of this event
   * between start (inclusive) and end (non-inclusive). Exceptions are taken
   * into account.
   *
   * @param aRangeStart     The (inclusive) date to start searching.
   * @param aRangeEnd       The (exclusive) date to end searching.
   * @param aMaxCount       The maximum number of occurrences to return
   *
   * @param aCount          The number of occurrences returned.
   * @return                The array of occurrences.
   */
  /* void getOccurrences (in calIDateTime aRangeStart, in calIDateTime aRangeEnd, in unsigned long aMaxCount, out unsigned long aCount, [array, size_is (aCount), retval] out calIItemBase aItems); */
  NS_IMETHOD GetOccurrences(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIItemBase ***aItems) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_CALIRECURRENCEINFO \
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable); \
  NS_IMETHOD MakeImmutable(void); \
  NS_IMETHOD Clone(calIRecurrenceInfo **_retval); \
  NS_IMETHOD GetItem(calIItemBase * *aItem); \
  NS_IMETHOD SetItem(calIItemBase * aItem); \
  NS_IMETHOD OnStartDateChange(calIDateTime *aNewStartTime, calIDateTime *aOldStartTime); \
  NS_IMETHOD GetRecurrenceItems(PRUint32 *aCount, calIRecurrenceItem ***aItems); \
  NS_IMETHOD SetRecurrenceItems(PRUint32 aCount, calIRecurrenceItem **aItems); \
  NS_IMETHOD CountRecurrenceItems(PRUint32 *_retval); \
  NS_IMETHOD ClearRecurrenceItems(void); \
  NS_IMETHOD AppendRecurrenceItem(calIRecurrenceItem *aItem); \
  NS_IMETHOD GetRecurrenceItemAt(PRUint32 aIndex, calIRecurrenceItem **_retval); \
  NS_IMETHOD DeleteRecurrenceItemAt(PRUint32 aIndex); \
  NS_IMETHOD DeleteRecurrenceItem(calIRecurrenceItem *aItem); \
  NS_IMETHOD InsertRecurrenceItemAt(calIRecurrenceItem *aItem, PRUint32 aIndex); \
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite); \
  NS_IMETHOD RemoveOccurrenceAt(calIDateTime *aRecurrenceId); \
  NS_IMETHOD RestoreOccurrenceAt(calIDateTime *aRecurrenceId); \
  NS_IMETHOD ModifyException(calIItemBase *anItem, PRBool aTakeOverOwnership); \
  NS_IMETHOD GetExceptionFor(calIDateTime *aRecurrenceId, PRBool aCreate, calIItemBase **_retval); \
  NS_IMETHOD RemoveExceptionFor(calIDateTime *aRecurrenceId); \
  NS_IMETHOD GetExceptionIds(PRUint32 *aCount, calIDateTime ***aIds); \
  NS_IMETHOD GetOccurrenceFor(calIDateTime *aRecurrenceId, calIItemBase **_retval); \
  NS_IMETHOD GetNextOccurrence(calIDateTime *aTime, calIItemBase **_retval); \
  NS_IMETHOD GetPreviousOccurrence(calIDateTime *aTime, calIItemBase **_retval); \
  NS_IMETHOD GetOccurrenceDates(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates); \
  NS_IMETHOD GetOccurrences(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIItemBase ***aItems); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_CALIRECURRENCEINFO(_to) \
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable) { return _to GetIsMutable(aIsMutable); } \
  NS_IMETHOD MakeImmutable(void) { return _to MakeImmutable(); } \
  NS_IMETHOD Clone(calIRecurrenceInfo **_retval) { return _to Clone(_retval); } \
  NS_IMETHOD GetItem(calIItemBase * *aItem) { return _to GetItem(aItem); } \
  NS_IMETHOD SetItem(calIItemBase * aItem) { return _to SetItem(aItem); } \
  NS_IMETHOD OnStartDateChange(calIDateTime *aNewStartTime, calIDateTime *aOldStartTime) { return _to OnStartDateChange(aNewStartTime, aOldStartTime); } \
  NS_IMETHOD GetRecurrenceItems(PRUint32 *aCount, calIRecurrenceItem ***aItems) { return _to GetRecurrenceItems(aCount, aItems); } \
  NS_IMETHOD SetRecurrenceItems(PRUint32 aCount, calIRecurrenceItem **aItems) { return _to SetRecurrenceItems(aCount, aItems); } \
  NS_IMETHOD CountRecurrenceItems(PRUint32 *_retval) { return _to CountRecurrenceItems(_retval); } \
  NS_IMETHOD ClearRecurrenceItems(void) { return _to ClearRecurrenceItems(); } \
  NS_IMETHOD AppendRecurrenceItem(calIRecurrenceItem *aItem) { return _to AppendRecurrenceItem(aItem); } \
  NS_IMETHOD GetRecurrenceItemAt(PRUint32 aIndex, calIRecurrenceItem **_retval) { return _to GetRecurrenceItemAt(aIndex, _retval); } \
  NS_IMETHOD DeleteRecurrenceItemAt(PRUint32 aIndex) { return _to DeleteRecurrenceItemAt(aIndex); } \
  NS_IMETHOD DeleteRecurrenceItem(calIRecurrenceItem *aItem) { return _to DeleteRecurrenceItem(aItem); } \
  NS_IMETHOD InsertRecurrenceItemAt(calIRecurrenceItem *aItem, PRUint32 aIndex) { return _to InsertRecurrenceItemAt(aItem, aIndex); } \
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite) { return _to GetIsFinite(aIsFinite); } \
  NS_IMETHOD RemoveOccurrenceAt(calIDateTime *aRecurrenceId) { return _to RemoveOccurrenceAt(aRecurrenceId); } \
  NS_IMETHOD RestoreOccurrenceAt(calIDateTime *aRecurrenceId) { return _to RestoreOccurrenceAt(aRecurrenceId); } \
  NS_IMETHOD ModifyException(calIItemBase *anItem, PRBool aTakeOverOwnership) { return _to ModifyException(anItem, aTakeOverOwnership); } \
  NS_IMETHOD GetExceptionFor(calIDateTime *aRecurrenceId, PRBool aCreate, calIItemBase **_retval) { return _to GetExceptionFor(aRecurrenceId, aCreate, _retval); } \
  NS_IMETHOD RemoveExceptionFor(calIDateTime *aRecurrenceId) { return _to RemoveExceptionFor(aRecurrenceId); } \
  NS_IMETHOD GetExceptionIds(PRUint32 *aCount, calIDateTime ***aIds) { return _to GetExceptionIds(aCount, aIds); } \
  NS_IMETHOD GetOccurrenceFor(calIDateTime *aRecurrenceId, calIItemBase **_retval) { return _to GetOccurrenceFor(aRecurrenceId, _retval); } \
  NS_IMETHOD GetNextOccurrence(calIDateTime *aTime, calIItemBase **_retval) { return _to GetNextOccurrence(aTime, _retval); } \
  NS_IMETHOD GetPreviousOccurrence(calIDateTime *aTime, calIItemBase **_retval) { return _to GetPreviousOccurrence(aTime, _retval); } \
  NS_IMETHOD GetOccurrenceDates(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates) { return _to GetOccurrenceDates(aRangeStart, aRangeEnd, aMaxCount, aCount, aDates); } \
  NS_IMETHOD GetOccurrences(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIItemBase ***aItems) { return _to GetOccurrences(aRangeStart, aRangeEnd, aMaxCount, aCount, aItems); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_CALIRECURRENCEINFO(_to) \
  NS_IMETHOD GetIsMutable(PRBool *aIsMutable) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsMutable(aIsMutable); } \
  NS_IMETHOD MakeImmutable(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->MakeImmutable(); } \
  NS_IMETHOD Clone(calIRecurrenceInfo **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Clone(_retval); } \
  NS_IMETHOD GetItem(calIItemBase * *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetItem(aItem); } \
  NS_IMETHOD SetItem(calIItemBase * aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetItem(aItem); } \
  NS_IMETHOD OnStartDateChange(calIDateTime *aNewStartTime, calIDateTime *aOldStartTime) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStartDateChange(aNewStartTime, aOldStartTime); } \
  NS_IMETHOD GetRecurrenceItems(PRUint32 *aCount, calIRecurrenceItem ***aItems) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRecurrenceItems(aCount, aItems); } \
  NS_IMETHOD SetRecurrenceItems(PRUint32 aCount, calIRecurrenceItem **aItems) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRecurrenceItems(aCount, aItems); } \
  NS_IMETHOD CountRecurrenceItems(PRUint32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CountRecurrenceItems(_retval); } \
  NS_IMETHOD ClearRecurrenceItems(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearRecurrenceItems(); } \
  NS_IMETHOD AppendRecurrenceItem(calIRecurrenceItem *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->AppendRecurrenceItem(aItem); } \
  NS_IMETHOD GetRecurrenceItemAt(PRUint32 aIndex, calIRecurrenceItem **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRecurrenceItemAt(aIndex, _retval); } \
  NS_IMETHOD DeleteRecurrenceItemAt(PRUint32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteRecurrenceItemAt(aIndex); } \
  NS_IMETHOD DeleteRecurrenceItem(calIRecurrenceItem *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteRecurrenceItem(aItem); } \
  NS_IMETHOD InsertRecurrenceItemAt(calIRecurrenceItem *aItem, PRUint32 aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->InsertRecurrenceItemAt(aItem, aIndex); } \
  NS_IMETHOD GetIsFinite(PRBool *aIsFinite) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsFinite(aIsFinite); } \
  NS_IMETHOD RemoveOccurrenceAt(calIDateTime *aRecurrenceId) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveOccurrenceAt(aRecurrenceId); } \
  NS_IMETHOD RestoreOccurrenceAt(calIDateTime *aRecurrenceId) { return !_to ? NS_ERROR_NULL_POINTER : _to->RestoreOccurrenceAt(aRecurrenceId); } \
  NS_IMETHOD ModifyException(calIItemBase *anItem, PRBool aTakeOverOwnership) { return !_to ? NS_ERROR_NULL_POINTER : _to->ModifyException(anItem, aTakeOverOwnership); } \
  NS_IMETHOD GetExceptionFor(calIDateTime *aRecurrenceId, PRBool aCreate, calIItemBase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExceptionFor(aRecurrenceId, aCreate, _retval); } \
  NS_IMETHOD RemoveExceptionFor(calIDateTime *aRecurrenceId) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveExceptionFor(aRecurrenceId); } \
  NS_IMETHOD GetExceptionIds(PRUint32 *aCount, calIDateTime ***aIds) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExceptionIds(aCount, aIds); } \
  NS_IMETHOD GetOccurrenceFor(calIDateTime *aRecurrenceId, calIItemBase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOccurrenceFor(aRecurrenceId, _retval); } \
  NS_IMETHOD GetNextOccurrence(calIDateTime *aTime, calIItemBase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNextOccurrence(aTime, _retval); } \
  NS_IMETHOD GetPreviousOccurrence(calIDateTime *aTime, calIItemBase **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPreviousOccurrence(aTime, _retval); } \
  NS_IMETHOD GetOccurrenceDates(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOccurrenceDates(aRangeStart, aRangeEnd, aMaxCount, aCount, aDates); } \
  NS_IMETHOD GetOccurrences(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIItemBase ***aItems) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOccurrences(aRangeStart, aRangeEnd, aMaxCount, aCount, aItems); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public calIRecurrenceInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_CALIRECURRENCEINFO

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, calIRecurrenceInfo)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute boolean isMutable; */
NS_IMETHODIMP _MYCLASS_::GetIsMutable(PRBool *aIsMutable)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void makeImmutable (); */
NS_IMETHODIMP _MYCLASS_::MakeImmutable()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIRecurrenceInfo clone (); */
NS_IMETHODIMP _MYCLASS_::Clone(calIRecurrenceInfo **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute calIItemBase item; */
NS_IMETHODIMP _MYCLASS_::GetItem(calIItemBase * *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP _MYCLASS_::SetItem(calIItemBase * aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onStartDateChange (in calIDateTime aNewStartTime, in calIDateTime aOldStartTime); */
NS_IMETHODIMP _MYCLASS_::OnStartDateChange(calIDateTime *aNewStartTime, calIDateTime *aOldStartTime)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getRecurrenceItems (out unsigned long aCount, [array, size_is (aCount), retval] out calIRecurrenceItem aItems); */
NS_IMETHODIMP _MYCLASS_::GetRecurrenceItems(PRUint32 *aCount, calIRecurrenceItem ***aItems)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setRecurrenceItems (in unsigned long aCount, [array, size_is (aCount)] in calIRecurrenceItem aItems); */
NS_IMETHODIMP _MYCLASS_::SetRecurrenceItems(PRUint32 aCount, calIRecurrenceItem **aItems)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long countRecurrenceItems (); */
NS_IMETHODIMP _MYCLASS_::CountRecurrenceItems(PRUint32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearRecurrenceItems (); */
NS_IMETHODIMP _MYCLASS_::ClearRecurrenceItems()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void appendRecurrenceItem (in calIRecurrenceItem aItem); */
NS_IMETHODIMP _MYCLASS_::AppendRecurrenceItem(calIRecurrenceItem *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIRecurrenceItem getRecurrenceItemAt (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::GetRecurrenceItemAt(PRUint32 aIndex, calIRecurrenceItem **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteRecurrenceItemAt (in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::DeleteRecurrenceItemAt(PRUint32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteRecurrenceItem (in calIRecurrenceItem aItem); */
NS_IMETHODIMP _MYCLASS_::DeleteRecurrenceItem(calIRecurrenceItem *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void insertRecurrenceItemAt (in calIRecurrenceItem aItem, in unsigned long aIndex); */
NS_IMETHODIMP _MYCLASS_::InsertRecurrenceItemAt(calIRecurrenceItem *aItem, PRUint32 aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isFinite; */
NS_IMETHODIMP _MYCLASS_::GetIsFinite(PRBool *aIsFinite)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeOccurrenceAt (in calIDateTime aRecurrenceId); */
NS_IMETHODIMP _MYCLASS_::RemoveOccurrenceAt(calIDateTime *aRecurrenceId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void restoreOccurrenceAt (in calIDateTime aRecurrenceId); */
NS_IMETHODIMP _MYCLASS_::RestoreOccurrenceAt(calIDateTime *aRecurrenceId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void modifyException (in calIItemBase anItem, in boolean aTakeOverOwnership); */
NS_IMETHODIMP _MYCLASS_::ModifyException(calIItemBase *anItem, PRBool aTakeOverOwnership)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIItemBase getExceptionFor (in calIDateTime aRecurrenceId, in boolean aCreate); */
NS_IMETHODIMP _MYCLASS_::GetExceptionFor(calIDateTime *aRecurrenceId, PRBool aCreate, calIItemBase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeExceptionFor (in calIDateTime aRecurrenceId); */
NS_IMETHODIMP _MYCLASS_::RemoveExceptionFor(calIDateTime *aRecurrenceId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getExceptionIds (out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aIds); */
NS_IMETHODIMP _MYCLASS_::GetExceptionIds(PRUint32 *aCount, calIDateTime ***aIds)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIItemBase getOccurrenceFor (in calIDateTime aRecurrenceId); */
NS_IMETHODIMP _MYCLASS_::GetOccurrenceFor(calIDateTime *aRecurrenceId, calIItemBase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIItemBase getNextOccurrence (in calIDateTime aTime); */
NS_IMETHODIMP _MYCLASS_::GetNextOccurrence(calIDateTime *aTime, calIItemBase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* calIItemBase getPreviousOccurrence (in calIDateTime aTime); */
NS_IMETHODIMP _MYCLASS_::GetPreviousOccurrence(calIDateTime *aTime, calIItemBase **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getOccurrenceDates (in calIDateTime aRangeStart, in calIDateTime aRangeEnd, in unsigned long aMaxCount, out unsigned long aCount, [array, size_is (aCount), retval] out calIDateTime aDates); */
NS_IMETHODIMP _MYCLASS_::GetOccurrenceDates(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIDateTime ***aDates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getOccurrences (in calIDateTime aRangeStart, in calIDateTime aRangeEnd, in unsigned long aMaxCount, out unsigned long aCount, [array, size_is (aCount), retval] out calIItemBase aItems); */
NS_IMETHODIMP _MYCLASS_::GetOccurrences(calIDateTime *aRangeStart, calIDateTime *aRangeEnd, PRUint32 aMaxCount, PRUint32 *aCount, calIItemBase ***aItems)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_calIRecurrenceInfo_h__ */
